# GeoCities for Python

This is a simple package which adds Cities and Countries search by name, address, long/lat, or geonames ID. **Returns geojson.**
[geocities](https://github.com/udartsev/geocities)

## Install
`pip install geonames`

or update:

`pip install -U geonames`

## Usage

```python
# test.py

```
## License
MIT